@@ -59,7 +59,11 @@
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 10, 0)
 #include <linux/magic.h>
 #endif
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 15, 0)
+#include <linux/stdarg.h>
+#else
 #include <stdarg.h>
+#endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 10, 0)
 #include <linux/uaccess.h>
 #else
@@ -113,6 +117,10 @@ struct path {
 #define __user
 #endif
 
+#ifndef fallthrough
+#define fallthrough do {} while (0)
+#endif
+
 #ifndef current_uid
 #define current_uid()   (current->uid)
 #endif
